# PyRoutePlanner

Calculate distances of polylines on street or topographical maps. 

This is particularly useful for those who wish to plan out hikes or runs and
would like to know the distance.

<center>
<img style='width:65%;' src='src/pyrouteplanner/docs/static/example1.png'>
</center>

## Current Features:

- Ability to place multiple polylines on the same map to compare distances
- Undo markers and clear active polylines
- Search for a location using Nominatim and center the map there
- Distance results in mi, km, m, ft

